EXPORTS
	??0DDynamicPowerResource@@QAE@ABVTDesC8@@H@Z @ 1 NONAME ; public: __thiscall DDynamicPowerResource::DDynamicPowerResource(class TDesC8 const &,int)
	??0DDynamicPowerResourceD@@QAE@ABVTDesC8@@H@Z @ 2 NONAME ; public: __thiscall DDynamicPowerResourceD::DDynamicPowerResourceD(class TDesC8 const &,int)
	??0DStaticPowerResource@@QAE@ABVTDesC8@@H@Z @ 3 NONAME ; public: __thiscall DStaticPowerResource::DStaticPowerResource(class TDesC8 const &,int)
	??1DDynamicPowerResource@@UAE@XZ @ 4 NONAME ; public: virtual __thiscall DDynamicPowerResource::~DDynamicPowerResource(void)
	??1DDynamicPowerResourceD@@UAE@XZ @ 5 NONAME ; public: virtual __thiscall DDynamicPowerResourceD::~DDynamicPowerResourceD(void)
	?AllocReserve@PowerResourceManager@@SAHIEE@Z @ 6 NONAME ; public: static int __cdecl PowerResourceManager::AllocReserve(unsigned int,unsigned char,unsigned char)
	?CancelAsyncRequestCallBack@PowerResourceManager@@SAHIIAAVTPowerResourceCb@@@Z @ 7 NONAME ; public: static int __cdecl PowerResourceManager::CancelAsyncRequestCallBack(unsigned int,unsigned int,class TPowerResourceCb &)
	?CancelNotification@PowerResourceManager@@SAHIIAAVDPowerResourceNotification@@@Z @ 8 NONAME ; public: static int __cdecl PowerResourceManager::CancelNotification(unsigned int,unsigned int,class DPowerResourceNotification &)
	?ChangeResourceState@PowerResourceManager@@SAHIIHPAVTPowerResourceCb@@@Z @ 9 NONAME ; public: static int __cdecl PowerResourceManager::ChangeResourceState(unsigned int,unsigned int,int,class TPowerResourceCb *)
	?ControlIO@PowerResourceManager@@SAHIIPAX00@Z @ 10 NONAME ; public: static int __cdecl PowerResourceManager::ControlIO(unsigned int,unsigned int,void *,void *,void *)
	?CreatePhysicalDevice@@YAPAVDPhysicalDevice@@XZ @ 11 NONAME ; class DPhysicalDevice * __cdecl CreatePhysicalDevice(void)
	?DeRegisterClient@PowerResourceManager@@SAHI@Z @ 12 NONAME ; public: static int __cdecl PowerResourceManager::DeRegisterClient(unsigned int)
	?DeRegisterClientLevelFromResource@PowerResourceManager@@SAHII@Z @ 13 NONAME ; public: static int __cdecl PowerResourceManager::DeRegisterClientLevelFromResource(unsigned int,unsigned int)
	?GetClientId@PowerResourceManager@@SAHIAAVTDesC8@@AAI@Z @ 14 NONAME ; public: static int __cdecl PowerResourceManager::GetClientId(unsigned int,class TDesC8 &,unsigned int &)
	?GetClientName@PowerResourceManager@@SAHIIAAVTDes8@@@Z @ 15 NONAME ; public: static int __cdecl PowerResourceManager::GetClientName(unsigned int,unsigned int,class TDes8 &)
	?GetInfo@DStaticPowerResource@@UBEHPAVTDes8@@@Z @ 16 NONAME ; public: virtual int __thiscall DStaticPowerResource::GetInfo(class TDes8 *)const 
	?GetInfoOnClientsUsingResource@PowerResourceManager@@SAHIIAAIPAX@Z @ 17 NONAME ; public: static int __cdecl PowerResourceManager::GetInfoOnClientsUsingResource(unsigned int,unsigned int,unsigned int &,void *)
	?GetInfoOnResourcesInUseByClient@PowerResourceManager@@SAHIIAAIPAX@Z @ 18 NONAME ; public: static int __cdecl PowerResourceManager::GetInfoOnResourcesInUseByClient(unsigned int,unsigned int,unsigned int &,void *)
	?GetNumClientsUsingResource@PowerResourceManager@@SAHIIAAI@Z @ 19 NONAME ; public: static int __cdecl PowerResourceManager::GetNumClientsUsingResource(unsigned int,unsigned int,unsigned int &)
	?GetNumResourcesInUseByClient@PowerResourceManager@@SAHIIAAI@Z @ 20 NONAME ; public: static int __cdecl PowerResourceManager::GetNumResourcesInUseByClient(unsigned int,unsigned int,unsigned int &)
	?GetResourceId@PowerResourceManager@@SAHIAAVTDesC8@@AAI@Z @ 21 NONAME ; public: static int __cdecl PowerResourceManager::GetResourceId(unsigned int,class TDesC8 &,unsigned int &)
	?GetResourceInfo@PowerResourceManager@@SAHIIPAX@Z @ 22 NONAME ; public: static int __cdecl PowerResourceManager::GetResourceInfo(unsigned int,unsigned int,void *)
	?GetResourceState@PowerResourceManager@@SAHIIHAAH0@Z @ 23 NONAME ; public: static int __cdecl PowerResourceManager::GetResourceState(unsigned int,unsigned int,int,int &,int &)
	?GetResourceState@PowerResourceManager@@SAHIIHAAVTPowerResourceCb@@@Z @ 24 NONAME ; public: static int __cdecl PowerResourceManager::GetResourceState(unsigned int,unsigned int,int,class TPowerResourceCb &)
	?HandleChangePropagation@DDynamicPowerResourceD@@UAEHUTPowerRequest@@W4TPropagation@@IABVTDesC8@@@Z @ 25 NONAME ; public: virtual int __thiscall DDynamicPowerResourceD::HandleChangePropagation(struct TPowerRequest,enum TPropagation,unsigned int,class TDesC8 const &)
	?InitController@DPowerResourceController@@SAHXZ @ 26 NONAME ; public: static int __cdecl DPowerResourceController::InitController(void)
	?PostBootLevel@DPowerResourceController@@SAHIH@Z @ 27 NONAME ; public: static int __cdecl DPowerResourceController::PostBootLevel(unsigned int,int)
	?RegisterClient@PowerResourceManager@@SAHAAIABVTDesC8@@W4TOwnerType@@@Z @ 28 NONAME ; public: static int __cdecl PowerResourceManager::RegisterClient(unsigned int &,class TDesC8 const &,enum TOwnerType)
	?RegisterStaticResource@DPowerResourceController@@SAHIPAVDStaticPowerResource@@@Z @ 29 NONAME ; public: static int __cdecl DPowerResourceController::RegisterStaticResource(unsigned int,class DStaticPowerResource *)
	?RequestNotification@PowerResourceManager@@SAHIIAAVDPowerResourceNotification@@@Z @ 30 NONAME ; public: static int __cdecl PowerResourceManager::RequestNotification(unsigned int,unsigned int,class DPowerResourceNotification &)
	?RequestNotification@PowerResourceManager@@SAHIIAAVDPowerResourceNotification@@HH@Z @ 31 NONAME ; public: static int __cdecl PowerResourceManager::RequestNotification(unsigned int,unsigned int,class DPowerResourceNotification &,int,int)
	?RegisterArrayOfStaticResources@DPowerResourceController@@SAHIAAPAPAVDStaticPowerResource@@I@Z @ 32 NONAME ; public: static int __cdecl DPowerResourceController::RegisterArrayOfStaticResources(unsigned int,class DStaticPowerResource * * &,unsigned int)

